# Copyright 2021 Fibocom Wireless Inc. All rights reserved.
# Copyright 2017 The Chromium OS Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
#!/bin/bash -e

readonly PROG="$(basename "$0")"
readonly LOG_TAG='modem-set-power'
chromeos_cfg_file="/etc/lsb-release"
# Starting from Coral Proto2, EN_PP3300_DX_LTE is controlled via this GPIO
EN_GPIO=432
readonly EN_GPIO_ON=1
readonly EN_GPIO_OFF=0

log_info() {
  logger -t "${LOG_TAG}" --id="$$" -p info "$*"
  echo "   INFO: $*" > /dev/stderr
}

log_warning() {
  logger -t "${LOG_TAG}" --id="$$" -p warn "$*"
  echo "WARNING: $*" > /dev/stderr
}

log_error() {
  logger -t "${LOG_TAG}" --id="$$" -p err "$*"
  echo "  ERROR: $*" > /dev/stderr
}

die() {
  log_error "$@"
  exit 1
}

set_modem_power() {
  local new_value="$1"

  local gpio_node=/sys/class/gpio/gpio"${EN_GPIO}"
  if [ ! -e "${gpio_node}" ]; then
    echo "${EN_GPIO}" > /sys/class/gpio/export
    [ -e "${gpio_node}" ] || die "Failed to export GPIO ${EN_GPIO}"
  fi

  local value_file="${gpio_node}"/value
  local old_value="$(cat "${value_file}")"
  if [ "${old_value}" != "${new_value}" ]; then
    echo 'out' > "${gpio_node}"/direction
    echo "${new_value}" > "${value_file}"
  fi
  old_value="$(cat "${value_file}")"
  [ "${old_value}" = "${new_value}" ] || die "Failed to update GPIO ${EN_GPIO}"
}

main() {
  local customer=""

  if [ ! -f "$chromeos_cfg_file" ]; then
    echo "$modemfwd_cfg_file is not exist"
	customer="other"
  else
    board_line=`cat /etc/lsb-release |grep CHROMEOS_RELEASE_BOARD`
    echo "$board_line" > board_newline
    customer=$(cut -d = -f 2 board_newline|cut -d - -f 1)
    rm -rf  board_newline
  fi

  echo "$customer"  
  
  if [ "$customer" == "nautilus" ];then
    echo "it's samsung platform, use EN_GPIO=432"
    EN_GPIO=432
  elif [ "$customer" == "brya" ];then
    echo "it's brya platform, use EN_GPIO=488"
    EN_GPIO=488
  elif [ "$customer" == "Guybrush" ];then
    echo "it's Guybrush platform, use EN_GPIO=280"
    EN_GPIO=280
  elif [ "$customer" == "coral" ];then
    echo "it's acer platform, use EN_GPIO=395"
    EN_GPIO=395
  elif [ "$customer" == "quanta" ];then
    echo "it's quanta platform, use EN_GPIO=395"
    EN_GPIO=395
  elif [ "$customer" == "sarien" ];then
    echo "it's dell platform, use EN_GPIO=311"
    EN_GPIO=311
  elif [ "$customer" == "drallion" ];then
    echo "it's drallion platform, use EN_GPIO=466"
    EN_GPIO=466
  elif [ "$customer" == "hatch" ];then
    echo "it's hatch platform, use EN_GPIO=218"
    EN_GPIO=218
  elif [ "$customer" == "dedede" ];then
    echo "it's dedede platform, use EN_GPIO=349"
    EN_GPIO=349
  elif [ "$customer" == "zork" ];then
    echo "it's zork platform, use EN_GPIO=345"
    EN_GPIO=345
  elif [ "$customer" == "octopus" ];then
    echo "it's octopus platform, use EN_GPIO=337"
    EN_GPIO=393
    set_modem_power "${EN_GPIO_ON}"
    EN_GPIO=499
	set_modem_power "${EN_GPIO_ON}"
	EN_GPIO=337
  else
  	echo "$customer customer not support"
	customer="other"
	exit
  fi

  set_modem_power "${EN_GPIO_OFF}"
  wait
}

main "$@"
